--
-- Drop tables always in the reverse order that they are created,
-- because of foreign key constraints
--
DROP TABLE IF EXISTS `SCBS_unidadeespecialidade`;
DROP TABLE IF EXISTS `SCBS_tipodoencasintoma`;
DROP TABLE IF EXISTS `SCBS_unidadesaude`;
DROP TABLE IF EXISTS `SCBS_tipodoenca`;
DROP TABLE IF EXISTS `SCBS_sintoma`;
DROP TABLE IF EXISTS `SCBS_queixadiversa`;
DROP TABLE IF EXISTS `SCBS_queixaanimal`;
DROP TABLE IF EXISTS `SCBS_queixaalimentar`;
DROP TABLE IF EXISTS `SCBS_queixa`;
DROP TABLE IF EXISTS `SCBS_funcionario`;
DROP TABLE IF EXISTS `SCBS_especialidade`;
DROP TABLE IF EXISTS `SCBS_endereco`;

--
-- Create the tables
--
CREATE TABLE `SCBS_endereco` (
  `codigo` varchar(50) default NULL,
  `rua` varchar(50) default NULL,
  `complemento` varchar(50) default NULL,
  `cep` varchar(50) default NULL,
  `uf` varchar(50) default NULL,
  `fone` varchar(50) default NULL,
  `cidade` varchar(50) default NULL,
  `bairro` varchar(50) default NULL,
  PRIMARY KEY  (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_especialidade` (
  `codigo` varchar(50) default NULL,
  `descricao` varchar(50) default NULL,
  PRIMARY KEY  (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_funcionario` (
  `login` varchar(50) default NULL,
  `nome` varchar(50) default NULL,
  `senha` varchar(50) default NULL,
  PRIMARY KEY (`login`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_queixa` (
  `ts` varchar(50) default NULL,
  `codigo` varchar(50) default NULL,
  `tipoqueixa` varchar(50) default NULL,
  `solicitante` varchar(50) default NULL,
  `descricao` varchar(50) default NULL,
  `observacao` varchar(50) default NULL,
  `email` varchar(50) default NULL,
  `funcionario` varchar(50) default NULL,
  `situacao` varchar(50) default NULL,
  `dataparecer` varchar(50) default NULL,
  `dataqueixa` varchar(50) default NULL,
  `enderecosolicitante` varchar(50) default NULL,
  PRIMARY KEY (`codigo`),
  CONSTRAINT `FKendereco_on_queixa` FOREIGN KEY (`enderecosolicitante`) REFERENCES `SCBS_endereco` (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_queixaalimentar` (
  `codigo` varchar(50) default NULL,
  `qtdecomensais` varchar(50) default NULL,
  `qtdedoentes` varchar(50) default NULL,
  `qtdeinternacoes` varchar(50) default NULL,
  `qtdeobitos` varchar(50) default NULL,
  `localatendimento` varchar(50) default NULL,
  `refeicaosuspeita` varchar(50) default NULL,
  `enderecodoente` varchar(50) default NULL,
  PRIMARY KEY (`codigo`),
  CONSTRAINT `FKendereco_on_queixaalimentar` FOREIGN KEY (`enderecodoente`) REFERENCES `SCBS_endereco` (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_queixaanimal` (
  `codigo` varchar(50) default NULL,
  `qtdeanimais` varchar(50) default NULL,
  `dataincomodo` varchar(50) default NULL,
  `animal` varchar(50) default NULL,
  `enderecolocalocorrencia` varchar(50) default NULL,
  PRIMARY KEY (`codigo`),
  CONSTRAINT `FKendereco_on_queixaanimal` FOREIGN KEY (`enderecolocalocorrencia`) REFERENCES `SCBS_endereco` (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_queixadiversa` (
  `codigo` varchar(50) default NULL,
  `idade` varchar(50) default NULL,
  `ocupacao` varchar(50) default NULL,
  `instrucao` varchar(50) default NULL,
  `enderecoocorrencia` varchar(50) default NULL,
  PRIMARY KEY (`codigo`),
  CONSTRAINT `FKendereco_on_queixadiversa` FOREIGN KEY (`enderecoocorrencia`) REFERENCES `SCBS_endereco` (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_sintoma` (
  `codigo` varchar(50) default NULL,
  `descricao` varchar(50) default NULL,
  PRIMARY KEY (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_tipodoenca` (
  `codigo` varchar(50) default NULL,
  `nome` varchar(50) default NULL,
  `descricao` varchar(50) default NULL,
  `manifestacao` varchar(50) default NULL,
  `duracao` varchar(50) default NULL,
  PRIMARY KEY (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_unidadesaude` (
  `codigo` varchar(50) default NULL,
  `descricao` varchar(50) default NULL,
  PRIMARY KEY (`codigo`)
) TYPE=InnoDB;

CREATE TABLE `SCBS_tipodoencasintoma` (
  `codigotipodoenca` varchar(50) default NULL,
  `codigosintoma` varchar(50) default NULL,
   CONSTRAINT `FKtipodoenca_on_tipodoencasintoma` FOREIGN KEY (`codigotipodoenca`) REFERENCES `SCBS_tipodoenca` (`codigo`),
   CONSTRAINT `FKsintoma_on_tipodoencasintoma` FOREIGN KEY (`codigosintoma`) REFERENCES `SCBS_sintoma` (`codigo`)   
) TYPE=InnoDB;

CREATE TABLE `SCBS_unidadeespecialidade` (
  `codigounidadesaude` varchar(50) default NULL,
  `codigoespecialidade` varchar(50) default NULL,
   CONSTRAINT `FKunidadesaude_on_unidadeespecialidade` FOREIGN KEY (`codigounidadesaude`) REFERENCES `SCBS_unidadesaude` (`codigo`),
   CONSTRAINT `FKespecialidade_on_unidadeespecialidade` FOREIGN KEY (`codigoespecialidade`) REFERENCES `SCBS_especialidade` (`codigo`)   
) TYPE=InnoDB;